@@ -6,7 +6,7 @@
  * supported. IFDH_MAX_READERS simultaneous readers are supported.
  *
  * This file was taken and modified from the Unix driver for
- * Towitoko smartcard readers. Used and re-licensed as BSD with
+ * Towitoko smart card readers. Used and re-licensed as BSD with
  * a permission from the author.
  *
  * Copyright (C) 1998-2001, Carlos Prados <cprados@yahoo.com>
@@ -50,8 +50,7 @@ typedef struct {
 } IFDH_Context;
 
 /* Matrix that stores conext information of all slots and readers */
-static IFDH_Context *ifdh_context[IFDH_MAX_READERS][IFDH_MAX_SLOTS] =
-{
+static IFDH_Context *ifdh_context[IFDH_MAX_READERS][IFDH_MAX_SLOTS] = {
 	{NULL},
 	{NULL},
 	{NULL},
@@ -60,8 +59,7 @@ static IFDH_Context *ifdh_context[IFDH_MAX_READERS][IFDH_MAX_SLOTS] =
 
 /* Mutexes for all readers */
 #ifdef HAVE_PTHREAD
-static pthread_mutex_t ifdh_context_mutex[IFDH_MAX_READERS] =
-{
+static pthread_mutex_t ifdh_context_mutex[IFDH_MAX_READERS] = {
 	PTHREAD_MUTEX_INITIALIZER,
 	PTHREAD_MUTEX_INITIALIZER,
 	PTHREAD_MUTEX_INITIALIZER,
@@ -72,15 +70,14 @@ static pthread_mutex_t ifdh_context_mutex[IFDH_MAX_READERS] =
 /* PC/SC Lite hotplugging base channel */
 #define HOTPLUG_BASE_PORT	0x200000
 
-RESPONSECODE
-IFDHCreateChannel(DWORD Lun, DWORD Channel)
+RESPONSECODE IFDHCreateChannel(DWORD Lun, DWORD Channel)
 {
 	char ret;
 	unsigned short ctn, pn, slot;
 	RESPONSECODE rv;
 
-	ctn = ((unsigned short) (Lun >> 16)) % IFDH_MAX_READERS;
-	slot = ((unsigned short) (Lun & 0x0000FFFF)) % IFDH_MAX_SLOTS;
+	ctn = ((unsigned short)(Lun >> 16)) % IFDH_MAX_READERS;
+	slot = ((unsigned short)(Lun & 0x0000FFFF)) % IFDH_MAX_SLOTS;
 
 #ifdef HAVE_PTHREAD
 	pthread_mutex_lock(&ifdh_context_mutex[ctn]);
@@ -101,10 +98,12 @@ IFDHCreateChannel(DWORD Lun, DWORD Channel)
 			/* Initialize context of the all slots in this reader */
 			for (slot = 0; slot < IFDH_MAX_SLOTS; slot++) {
 				ifdh_context[ctn][slot] =
-				    (IFDH_Context *) malloc(sizeof(IFDH_Context));
+				    (IFDH_Context *)
+				    malloc(sizeof(IFDH_Context));
 
 				if (ifdh_context[ctn][slot] != NULL)
-					memset(ifdh_context[ctn][slot], 0, sizeof(IFDH_Context));
+					memset(ifdh_context[ctn][slot], 0,
+					       sizeof(IFDH_Context));
 			}
 			rv = IFD_SUCCESS;
 		} else {
@@ -119,21 +118,20 @@ IFDHCreateChannel(DWORD Lun, DWORD Channel)
 	pthread_mutex_unlock(&ifdh_context_mutex[ctn]);
 #endif
 #ifdef DEBUG_IFDH
-	syslog(LOG_INFO, "IFDH: IFDHCreateChannel(Lun=0x%X, Channel=0x%X)=%d", Lun,
-	       Channel, rv);
+	syslog(LOG_INFO, "IFDH: IFDHCreateChannel(Lun=0x%X, Channel=0x%X)=%d",
+	       Lun, Channel, rv);
 #endif
 	return rv;
 }
 
-RESPONSECODE
-IFDHCloseChannel(DWORD Lun)
+RESPONSECODE IFDHCloseChannel(DWORD Lun)
 {
 	char ret;
 	unsigned short ctn, slot;
 	RESPONSECODE rv;
 
-	ctn = ((unsigned short) (Lun >> 16)) % IFDH_MAX_READERS;
-	slot = ((unsigned short) (Lun & 0x0000FFFF)) % IFDH_MAX_SLOTS;
+	ctn = ((unsigned short)(Lun >> 16)) % IFDH_MAX_READERS;
+	slot = ((unsigned short)(Lun & 0x0000FFFF)) % IFDH_MAX_SLOTS;
 
 	ret = CT_close(ctn);
 
@@ -167,8 +165,8 @@ IFDHGetCapabilities(DWORD Lun, DWORD Tag, PDWORD Length, PUCHAR Value)
 	unsigned short ctn, slot;
 	RESPONSECODE rv;
 
-	ctn = ((unsigned short) (Lun >> 16)) % IFDH_MAX_READERS;
-	slot = ((unsigned short) (Lun & 0x0000FFFF)) % IFDH_MAX_SLOTS;
+	ctn = ((unsigned short)(Lun >> 16)) % IFDH_MAX_READERS;
+	slot = ((unsigned short)(Lun & 0x0000FFFF)) % IFDH_MAX_SLOTS;
 
 #ifdef HAVE_PTHREAD
 	pthread_mutex_lock(&ifdh_context_mutex[ctn]);
@@ -176,7 +174,8 @@ IFDHGetCapabilities(DWORD Lun, DWORD Tag, PDWORD Length, PUCHAR Value)
 	switch (Tag) {
 	case TAG_IFD_ATR:
 		(*Length) = ifdh_context[ctn][slot]->ATR_Length;
-		memcpy(Value, ifdh_context[ctn][slot]->icc_state.ATR, (*Length));
+		memcpy(Value, ifdh_context[ctn][slot]->icc_state.ATR,
+		       (*Length));
 		rv = IFD_SUCCESS;
 		break;
 
@@ -200,7 +199,8 @@ IFDHGetCapabilities(DWORD Lun, DWORD Tag, PDWORD Length, PUCHAR Value)
 	pthread_mutex_unlock(&ifdh_context_mutex[ctn]);
 #endif
 #ifdef DEBUG_IFDH
-	syslog(LOG_INFO, "IFDH: IFDHGetCapabilities (Lun=0x%X, Tag=0x%X)=%d", Lun, Tag, rv);
+	syslog(LOG_INFO, "IFDH: IFDHGetCapabilities (Lun=0x%X, Tag=0x%X)=%d",
+	       Lun, Tag, rv);
 #endif
 	return rv;
 }
@@ -210,8 +210,8 @@ IFDHSetCapabilities(DWORD Lun, DWORD Tag, DWORD Length, PUCHAR Value)
 {
 #ifdef DEBUG_IFDH
 #if 0
-	syslog(LOG_INFO, "IFDH: IFDHSetCapabilities (Lun=%X, Tag=%X)=%d", Lun, Tag,
-	       IFD_NOT_SUPPORTED);
+	syslog(LOG_INFO, "IFDH: IFDHSetCapabilities (Lun=%X, Tag=%X)=%d", Lun,
+	       Tag, IFD_NOT_SUPPORTED);
 #endif
 #endif
 	return IFD_NOT_SUPPORTED;
@@ -226,20 +226,20 @@ IFDHSetProtocolParameters(DWORD Lun, DWORD Protocol,
 	UCHAR cmd[10], rsp[256], sad, dad;
 	RESPONSECODE rv;
 
-	ctn = ((unsigned short) (Lun >> 16)) % IFDH_MAX_READERS;
-	slot = ((unsigned short) (Lun & 0x0000FFFF)) % IFDH_MAX_SLOTS;
+	ctn = ((unsigned short)(Lun >> 16)) % IFDH_MAX_READERS;
+	slot = ((unsigned short)(Lun & 0x0000FFFF)) % IFDH_MAX_SLOTS;
 
 #ifdef HAVE_PTHREAD
 	pthread_mutex_lock(&ifdh_context_mutex[ctn]);
 #endif
 	if (ifdh_context[ctn][slot] != NULL) {
 		cmd[0] = CTBCS_CLA_2;
-               cmd[1] = CTBCS_INS_SET_INTERFACE_PARAM;
-               cmd[2] = (UCHAR) (slot + 1);
-               cmd[3] = 0x00;
-               cmd[4] = 0x03;
-               cmd[5] = CTBCS_TAG_TPP;
-               cmd[6] = 0x01;
+		cmd[1] = CTBCS_INS_SET_INTERFACE_PARAM;
+		cmd[2] = (UCHAR) (slot + 1);
+		cmd[3] = 0x00;
+		cmd[4] = 0x03;
+		cmd[5] = CTBCS_TAG_TPP;
+		cmd[6] = 0x01;
 		cmd[7] = Protocol & 0xFF;
 
 		lc = 8;
@@ -250,7 +250,7 @@ IFDHSetProtocolParameters(DWORD Lun, DWORD Protocol,
 
 		ret = CT_data(ctn, &dad, &sad, lc, cmd, &lr, rsp);
 
-		if (ret == OK)  {
+		if (ret == OK) {
 			rv = IFD_SUCCESS;
 		} else {
 			rv = IFD_ERROR_PTS_FAILURE;
@@ -262,22 +262,22 @@ IFDHSetProtocolParameters(DWORD Lun, DWORD Protocol,
 	pthread_mutex_unlock(&ifdh_context_mutex[ctn]);
 #endif
 #ifdef DEBUG_IFDH
-	syslog(LOG_INFO, "IFDH: IFDHSetProtocolParameters (Lun=0x%X, Protocol=%d, Flags=0x%02X, PTS1=0x%02X, PTS2=0x%02X, PTS3=0x%02X)=%d",
+	syslog(LOG_INFO,
+	       "IFDH: IFDHSetProtocolParameters (Lun=0x%X, Protocol=%d, Flags=0x%02X, PTS1=0x%02X, PTS2=0x%02X, PTS3=0x%02X)=%d",
 	       Lun, Protocol, Flags, PTS1, PTS2, PTS3, rv);
 #endif
 	return rv;
 }
 
-RESPONSECODE
-IFDHPowerICC(DWORD Lun, DWORD Action, PUCHAR Atr, PDWORD AtrLength)
+RESPONSECODE IFDHPowerICC(DWORD Lun, DWORD Action, PUCHAR Atr, PDWORD AtrLength)
 {
 	char ret;
 	unsigned short ctn, slot, lc, lr;
 	UCHAR cmd[5], rsp[256], sad, dad;
 	RESPONSECODE rv;
 
-	ctn = ((unsigned short) (Lun >> 16)) % IFDH_MAX_READERS;
-	slot = ((unsigned short) (Lun & 0x0000FFFF)) % IFDH_MAX_SLOTS;
+	ctn = ((unsigned short)(Lun >> 16)) % IFDH_MAX_READERS;
+	slot = ((unsigned short)(Lun & 0x0000FFFF)) % IFDH_MAX_SLOTS;
 
 #ifdef HAVE_PTHREAD
 	pthread_mutex_lock(&ifdh_context_mutex[ctn]);
@@ -298,8 +298,10 @@ IFDHPowerICC(DWORD Lun, DWORD Action, PUCHAR Atr, PDWORD AtrLength)
 			ret = CT_data(ctn, &dad, &sad, 5, cmd, &lr, rsp);
 
 			if ((ret == OK) && (lr >= 2)) {
-				ifdh_context[ctn][slot]->ATR_Length = (DWORD) lr - 2;
-				memcpy(ifdh_context[ctn][slot]->icc_state.ATR, rsp, lr - 2);
+				ifdh_context[ctn][slot]->ATR_Length =
+				    (DWORD) lr - 2;
+				memcpy(ifdh_context[ctn][slot]->icc_state.ATR,
+				       rsp, lr - 2);
 
 				(*AtrLength) = (DWORD) lr - 2;
 				memcpy(Atr, rsp, lr - 2);
@@ -324,7 +326,8 @@ IFDHPowerICC(DWORD Lun, DWORD Action, PUCHAR Atr, PDWORD AtrLength)
 
 			if (ret == OK) {
 				ifdh_context[ctn][slot]->ATR_Length = 0;
-				memset(ifdh_context[ctn][slot]->icc_state.ATR, 0, MAX_ATR_SIZE);
+				memset(ifdh_context[ctn][slot]->icc_state.ATR,
+				       0, MAX_ATR_SIZE);
 
 				(*AtrLength) = 0;
 				rv = IFD_SUCCESS;
@@ -346,8 +349,10 @@ IFDHPowerICC(DWORD Lun, DWORD Action, PUCHAR Atr, PDWORD AtrLength)
 			ret = CT_data(ctn, &dad, &sad, 5, cmd, &lr, rsp);
 
 			if ((ret == OK) && (lr >= 2)) {
-				ifdh_context[ctn][slot]->ATR_Length = (DWORD) lr - 2;
-				memcpy(ifdh_context[ctn][slot]->icc_state.ATR, rsp, lr - 2);
+				ifdh_context[ctn][slot]->ATR_Length =
+				    (DWORD) lr - 2;
+				memcpy(ifdh_context[ctn][slot]->icc_state.ATR,
+				       rsp, lr - 2);
 
 				(*AtrLength) = (DWORD) lr - 2;
 				memcpy(Atr, rsp, lr - 2);
@@ -366,7 +371,8 @@ IFDHPowerICC(DWORD Lun, DWORD Action, PUCHAR Atr, PDWORD AtrLength)
 	pthread_mutex_unlock(&ifdh_context_mutex[ctn]);
 #endif
 #ifdef DEBUG_IFDH
-	syslog(LOG_INFO, "IFDH: IFDHPowerICC (Lun=0x%X, Action=0x%X)=%d", Lun, Action, rv);
+	syslog(LOG_INFO, "IFDH: IFDHPowerICC (Lun=0x%X, Action=0x%X)=%d", Lun,
+	       Action, rv);
 #endif
 	return rv;
 }
@@ -381,8 +387,8 @@ IFDHTransmitToICC(DWORD Lun, SCARD_IO_HEADER SendPci,
 	UCHAR sad, dad;
 	RESPONSECODE rv;
 
-	ctn = ((unsigned short) (Lun >> 16)) % IFDH_MAX_READERS;
-	slot = ((unsigned short) (Lun & 0x0000FFFF)) % IFDH_MAX_SLOTS;
+	ctn = ((unsigned short)(Lun >> 16)) % IFDH_MAX_READERS;
+	slot = ((unsigned short)(Lun & 0x0000FFFF)) % IFDH_MAX_SLOTS;
 
 #ifdef HAVE_PTHREAD
 	pthread_mutex_lock(&ifdh_context_mutex[ctn]);
@@ -393,8 +399,8 @@ IFDHTransmitToICC(DWORD Lun, SCARD_IO_HEADER SendPci,
 #endif
 		dad = (UCHAR) ((slot == 0) ? 0x00 : slot + 1);
 		sad = 0x02;
-		lr = (unsigned short) (*RxLength);
-		lc = (unsigned short) TxLength;
+		lr = (unsigned short)(*RxLength);
+		lc = (unsigned short)TxLength;
 
 		ret = CT_data(ctn, &dad, &sad, lc, TxBuffer, &lr, RxBuffer);
 
@@ -412,7 +418,8 @@ IFDHTransmitToICC(DWORD Lun, SCARD_IO_HEADER SendPci,
 		rv = IFD_ICC_NOT_PRESENT;
 	}
 #ifdef DEBUG_IFDH
-	syslog(LOG_INFO, "IFDH: IFDHTransmitToICC (Lun=0x%X, Tx=%u, Rx=%u)=%d", Lun, TxLength, (*RxLength), rv);
+	syslog(LOG_INFO, "IFDH: IFDHTransmitToICC (Lun=0x%X, Tx=%u, Rx=%u)=%d",
+	       Lun, TxLength, (*RxLength), rv);
 #endif
 	return rv;
 }
@@ -426,8 +433,8 @@ IFDHControl(DWORD Lun, PUCHAR TxBuffer,
 	UCHAR sad, dad;
 	RESPONSECODE rv;
 
-	ctn = ((unsigned short) (Lun >> 16)) % IFDH_MAX_READERS;
-	slot = ((unsigned short) (Lun & 0x0000FFFF)) % IFDH_MAX_SLOTS;
+	ctn = ((unsigned short)(Lun >> 16)) % IFDH_MAX_READERS;
+	slot = ((unsigned short)(Lun & 0x0000FFFF)) % IFDH_MAX_SLOTS;
 
 #ifdef HAVE_PTHREAD
 	pthread_mutex_lock(&ifdh_context_mutex[ctn]);
@@ -438,8 +445,8 @@ IFDHControl(DWORD Lun, PUCHAR TxBuffer,
 #endif
 		dad = 0x01;
 		sad = 0x02;
-		lr = (unsigned short) (*RxLength);
-		lc = (unsigned short) TxLength;
+		lr = (unsigned short)(*RxLength);
+		lc = (unsigned short)TxLength;
 
 		ret = CT_data(ctn, &dad, &sad, lc, TxBuffer, &lr, RxBuffer);
 
@@ -457,21 +464,21 @@ IFDHControl(DWORD Lun, PUCHAR TxBuffer,
 		rv = IFD_ICC_NOT_PRESENT;
 	}
 #ifdef DEBUG_IFDH
-	syslog(LOG_INFO, "IFDH: IFDHControl (Lun=0x%X, Tx=%u, Rx=%u)=%d", Lun, TxLength, (*RxLength), rv);
+	syslog(LOG_INFO, "IFDH: IFDHControl (Lun=0x%X, Tx=%u, Rx=%u)=%d", Lun,
+	       TxLength, (*RxLength), rv);
 #endif
 	return rv;
 }
 
-RESPONSECODE
-IFDHICCPresence(DWORD Lun)
+RESPONSECODE IFDHICCPresence(DWORD Lun)
 {
 	char ret;
 	unsigned short ctn, slot, lc, lr;
 	UCHAR cmd[5], rsp[256], sad, dad;
 	RESPONSECODE rv;
 
-	ctn = ((unsigned short) (Lun >> 16)) % IFDH_MAX_READERS;
-	slot = ((unsigned short) (Lun & 0x0000FFFF)) % IFDH_MAX_SLOTS;
+	ctn = ((unsigned short)(Lun >> 16)) % IFDH_MAX_READERS;
+	slot = ((unsigned short)(Lun & 0x0000FFFF)) % IFDH_MAX_SLOTS;
 
 	cmd[0] = CTBCS_CLA;
 	cmd[1] = CTBCS_INS_STATUS;
