@@ -19,22 +19,21 @@
 #include <openct/logging.h>
 #include <openct/error.h>
 
-static void	usage(int exval);
-static void     version(void);
-static int	do_reset(ct_handle *, unsigned char *, size_t);
-static void	do_select_mf(ct_handle *reader);
-static void	do_read_memory(ct_handle *, unsigned int, unsigned int);
-static void	print_reader(ct_handle *h);
-static void	print_reader_info(ct_info_t *info);
-static void	print_atr(ct_handle *, unsigned char *, size_t);
-static void	dump(unsigned char *data, size_t len);
+static void usage(int exval);
+static void version(void);
+static int do_reset(ct_handle *, unsigned char *, size_t);
+static void do_select_mf(ct_handle * reader);
+static void do_read_memory(ct_handle *, unsigned int, unsigned int);
+static void print_reader(ct_handle * h);
+static void print_reader_info(ct_info_t * info);
+static void print_atr(ct_handle *, unsigned char *, size_t);
+static void dump(unsigned char *data, size_t len);
 
-
-static unsigned int	opt_reader = 0;
-static unsigned int	opt_slot = 0;
-static const char *	opt_config = NULL;
-static int		opt_debug = 0;
-static int		opt_command = -1;
+static unsigned int opt_reader = 0;
+static unsigned int opt_slot = 0;
+static const char *opt_config = NULL;
+static int opt_debug = 0;
+static int opt_command = -1;
 
 enum {
 	CMD_LIST = 0,
@@ -46,16 +45,15 @@ enum {
 	CMD_VERSION,
 };
 
-int
-main(int argc, char **argv)
+int main(int argc, char **argv)
 {
-	unsigned char	atr[64];
-	const char	*cmd;
-	ct_handle	*h;
-	ct_lock_handle	lock;
-	int		c, rc;
+	unsigned char atr[64];
+	const char *cmd;
+	ct_handle *h;
+	ct_lock_handle lock;
+	int c, rc;
 
-	while ((c = getopt(argc, argv, "df:r:hv")) != -1) {
+	while ((c = getopt(argc, argv, "df:r:s:hv")) != -1) {
 		switch (c) {
 		case 'd':
 			opt_debug++;
@@ -70,6 +68,9 @@ main(int argc, char **argv)
 		case 'r':
 			opt_reader = atoi(optarg);
 			break;
+		case 's':
+			opt_slot = atoi(optarg);
+			break;
 		default:
 			usage(1);
 		}
@@ -93,16 +94,15 @@ main(int argc, char **argv)
 	else if (!strcmp(cmd, "read"))
 		opt_command = CMD_READ;
 	else {
-		fprintf(stderr,
-			"Unknown command \"%s\"\n", cmd);
+		fprintf(stderr, "Unknown command \"%s\"\n", cmd);
 		usage(1);
 	}
 
 	if (opt_command == CMD_LIST) {
-		int	i;
+		int i;
 
 		for (i = 0; i < OPENCT_MAX_READERS; i++) {
-			ct_info_t	info;
+			ct_info_t info;
 
 			if (ct_reader_info(i, &info) < 0)
 				continue;
@@ -116,7 +116,7 @@ main(int argc, char **argv)
 	if (opt_command == CMD_RWAIT) {
 		while (1) {
 			h = ct_reader_connect(opt_reader);
-			if (h)  { 
+			if (h) {
 				free(h);
 				break;
 			}
@@ -131,7 +131,7 @@ main(int argc, char **argv)
 	}
 
 	if (opt_command == CMD_WAIT) {
-		int	status;
+		int status;
 
 		while (1) {
 			if ((rc = ct_card_status(h, opt_slot, &status)) < 0) {
@@ -151,7 +151,7 @@ main(int argc, char **argv)
 	printf("Detected ");
 	print_reader(h);
 
-	if ((rc = ct_card_lock(h, 0, IFD_LOCK_SHARED, &lock)) < 0) {
+	if ((rc = ct_card_lock(h, opt_slot, IFD_LOCK_SHARED, &lock)) < 0) {
 		fprintf(stderr, "ct_card_lock: err=%d\n", rc);
 		exit(1);
 	}
@@ -167,8 +167,8 @@ main(int argc, char **argv)
 		do_select_mf(h);
 		break;
 
-	case CMD_READ: {
-			unsigned int	address = 0, count = 1024;
+	case CMD_READ:{
+			unsigned int address = 0, count = 1024;
 
 			if (optind < argc)
 				address = strtoul(argv[optind++], NULL, 0);
@@ -184,55 +184,51 @@ main(int argc, char **argv)
 	return 0;
 }
 
-void
-version(void)
+void version(void)
 {
-	fprintf(stdout,"OpenCT " VERSION "\n");
+	fprintf(stdout, "OpenCT " VERSION "\n");
 	exit(0);
 }
 
-void
-usage(int exval)
+void usage(int exval)
 {
 	fprintf(exval ? stderr : stdout,
-"usage: openct-tool [-d] [-f configfile] [-r reader] command ...\n"
-"  -d   enable debugging; repeat to increase verbosity\n"
-"  -f   specify config file (default %s)\n"
-"  -r   specify index of reader to use\n"
-"  -h   display this message\n"
-"  -v   display version and exit\n"
-"\n"
-"command: can be one of the following\n"
-" list  list all readers found\n"
-" atr   print ATR of card in selected reader\n"
-" wait  wait for card to be inserted\n"
-" rwait wait for reader to be attached\n"
-" mf    try to select main folder of card\n"
-" read  dump memory of synchronous card\n",
-OPENCT_CONF_PATH
-);
+		"usage: openct-tool [-d] [-f configfile] [-r reader] command ...\n"
+		"  -d   enable debugging; repeat to increase verbosity\n"
+		"  -f   specify config file (default %s)\n"
+		"  -r   specify index of reader to use\n"
+		"  -s   specify slot of reader to use\n"
+		"  -h   display this message\n"
+		"  -v   display version and exit\n"
+		"\n"
+		"command: can be one of the following\n"
+		" list  list all readers found\n"
+		" atr   print ATR of card in selected reader\n"
+		" wait  wait for card to be inserted\n"
+		" rwait wait for reader to be attached\n"
+		" mf    try to select main folder of card\n"
+		" read  dump memory of synchronous card\n", OPENCT_CONF_PATH);
 	exit(exval);
 }
 
-int
-do_reset(ct_handle *h, unsigned char *atr, size_t atr_len)
+int do_reset(ct_handle * h, unsigned char *atr, size_t atr_len)
 {
-	int	rc, n, status;
+	int rc, n, status;
 
-	if ((rc = ct_card_status(h, 0, &status)) < 0) {
+	if ((rc = ct_card_status(h, opt_slot, &status)) < 0) {
 		fprintf(stderr, "ct_card_status: err=%d\n", rc);
 		exit(1);
 	}
 
 	printf("Card %spresent%s\n",
-			(status & IFD_CARD_PRESENT)? "" : "not ",
-			(status & IFD_CARD_STATUS_CHANGED)? ", status changed" : "");
+	       (status & IFD_CARD_PRESENT) ? "" : "not ",
+	       (status & IFD_CARD_STATUS_CHANGED) ? ", status changed" : "");
 
 	if (status & IFD_CARD_PRESENT) {
-		n = ct_card_reset(h, 0, atr, atr_len);
+		n = ct_card_reset(h, opt_slot, atr, atr_len);
 	} else {
-		n = ct_card_request(h, 0, 5, "Please insert card",
-				atr, atr_len);
+		n = ct_card_request(h, opt_slot, 5, "Please insert card",
+				    atr, atr_len);
 	}
 
 	if (n < 0) {
@@ -243,21 +239,21 @@ do_reset(ct_handle *h, unsigned char *atr, size_t atr_len)
 	return n;
 }
 
-void
-do_select_mf(ct_handle *h)
+void do_select_mf(ct_handle * h)
 {
-	unsigned char	cmd[] = { 0x00, 0xA4, 0x00, 0x00, 0x02, 0x3f, 0x00, 0x00 };
-	unsigned char	res[256];
-	ct_lock_handle	lock;
-	int		rc;
+	unsigned char cmd[] =
+	    { 0x00, 0xA4, 0x00, 0x00, 0x02, 0x3f, 0x00, 0x00 };
+	unsigned char res[256];
+	ct_lock_handle lock;
+	int rc;
 
-	if ((rc = ct_card_lock(h, 0, IFD_LOCK_EXCLUSIVE, &lock)) < 0) {
+	if ((rc = ct_card_lock(h, opt_slot, IFD_LOCK_EXCLUSIVE, &lock)) < 0) {
 		fprintf(stderr, "ct_card_lock: err=%d\n", rc);
 		exit(1);
 	}
 
-again:
-	rc = ct_card_transact(h, 0, cmd, sizeof(cmd), res, sizeof(res));
+      again:
+	rc = ct_card_transact(h, opt_slot, cmd, sizeof(cmd), res, sizeof(res));
 	if (rc < 0) {
 		fprintf(stderr, "card communication failure, err=%d\n", rc);
 		return;
@@ -275,21 +271,18 @@ again:
 	dump(res, rc);
 }
 
-void
-do_read_memory(ct_handle *h, unsigned int address, unsigned int count)
+void do_read_memory(ct_handle * h, unsigned int address, unsigned int count)
 {
-	unsigned char	buffer[8192];
-	int		rc;
+	unsigned char buffer[8192];
+	int rc;
 
 	if (count > sizeof(buffer))
 		count = sizeof(buffer);
 
-	rc = ct_card_read_memory(h, opt_slot,
-			address, buffer, count);
+	rc = ct_card_read_memory(h, opt_slot, address, buffer, count);
 	if (rc < 0) {
 		fprintf(stderr,
-			"failed to read memory card: %s\n",
-			ct_strerror(rc));
+			"failed to read memory card: %s\n", ct_strerror(rc));
 		exit(1);
 	}
 
@@ -297,11 +290,10 @@ do_read_memory(ct_handle *h, unsigned int address, unsigned int count)
 	dump(buffer, rc);
 }
 
-void
-print_reader(ct_handle *h)
+void print_reader(ct_handle * h)
 {
-	ct_info_t	info;
-	int		rc;
+	ct_info_t info;
+	int rc;
 
 	if ((rc = ct_reader_status(h, &info)) < 0) {
 		printf("ct_reader_status: err=%d\n", rc);
@@ -310,10 +302,9 @@ print_reader(ct_handle *h)
 	}
 }
 
-void
-print_reader_info(ct_info_t *info)
+void print_reader_info(ct_info_t * info)
 {
-	const char	*sepa;
+	const char *sepa;
 
 	printf("%s", info->ct_name);
 
@@ -335,10 +326,9 @@ print_reader_info(ct_info_t *info)
 	printf("\n");
 }
 
-void
-print_atr(ct_handle *h, unsigned char *atr, size_t len)
+void print_atr(ct_handle * h, unsigned char *atr, size_t len)
 {
-	unsigned int	m;
+	unsigned int m;
 
 	printf("ATR:");
 	if (len == 0) {
@@ -350,8 +340,7 @@ print_atr(ct_handle *h, unsigned char *atr, size_t len)
 	printf("\n");
 }
 
-void
-dump(unsigned char *data, size_t len)
+void dump(unsigned char *data, size_t len)
 {
 	unsigned int offset = 0;
 
@@ -361,13 +350,13 @@ dump(unsigned char *data, size_t len)
 		printf("%04x:", offset);
 		for (i = 0; i < 16; i++) {
 			if (offset + i < len)
-				printf(" %02x", data[offset+i]);
+				printf(" %02x", data[offset + i]);
 			else
 				printf("   ");
 		}
 		printf("   ");
 		for (i = 0; i < 16 && offset + i < len; i++) {
-			int	c = data[offset+i];
+			int c = data[offset + i];
 
 			if (!isprint(c) || (isspace(c) && c != ' '))
 				c = '.';
